@@ -1,7 +1,6 @@
 """Provides Liquid class"""
 import builtins
-from os import PathLike
-from typing import Any, Callable, Mapping, Sequence, Union
+from typing import Any, Callable, Mapping
 from jinja2 import (
     Environment,
     ChoiceLoader,
@@ -9,6 +8,8 @@ from jinja2 import (
 )
 
 from .filters.standard import standard_filter_manager
+from .utils import PathType, PathTypeOrIter
+
 
 class Liquid:
     """The entrance for the package
@@ -36,6 +37,8 @@ class Liquid:
             `FileSystemLoader`
         globals: Additional global values to be used to render the template
         filters: Additional filters be to used to render the template
+        filters_as_globals: Whether also use filters as globals
+            Only works in wild mode
         **kwargs: Other arguments for an jinja Environment construction and
             configurations for extensions
     """
@@ -44,19 +47,18 @@ class Liquid:
 
     def __init__(
         self,
-        template: PathLike,
+        template: PathType,
         from_file: bool = None,
         mode: str = None,
         env: Environment = None,
         filter_with_colon: bool = None,
-        search_paths: Union[PathLike, Sequence[PathLike]] = None,
-        # pylint: disable=redefined-builtin
+        search_paths: PathTypeOrIter = None,
         globals: Mapping[str, Any] = None,
         filters: Mapping[str, Callable] = None,
+        filters_as_globals: bool = None,
         **kwargs: Any,
     ) -> None:
         """Constructor"""
-        # pylint: disable=too-many-statements,too-many-branches
         # default values
         # fetch at runtime, so that they can be configured at importing
         from .defaults import (
@@ -66,6 +68,7 @@ class Liquid:
             SEARCH_PATHS,
             ENV_ARGS,
             SHARED_GLOBALS,
+            FILTERS_AS_GLOBALS,
         )
 
         if from_file is None:
@@ -76,6 +79,8 @@ class Liquid:
             filter_with_colon = FILTER_WITH_COLON
         if search_paths is None:
             search_paths = SEARCH_PATHS
+        if filters_as_globals is None:
+            filters_as_globals = FILTERS_AS_GLOBALS
 
         # split kwargs into arguments for Environment constructor and
         # configurations for extensions
@@ -143,6 +148,9 @@ class Liquid:
                     if not key.startswith("_")
                 }
             )
+            if filters_as_globals:
+                env.globals.update(standard_filter_manager.filters)
+                env.globals.update(wild_filter_manager.filters)
 
         elif mode == "jekyll":
             from .exts.front_matter import FrontMatterExtension
@@ -167,11 +175,20 @@ class Liquid:
 
         if filters:
             env.filters.update(filters)
+
+        builtin_globals = {
+            "int": int,
+            "float": float,
+            "str": str,
+            "bool": bool
+        }
         if globals:
-            env.globals.update(globals)
+            builtin_globals.update(globals)
+        env.globals.update(builtin_globals)
 
         if from_file:
-            self.template = env.get_template(template)
+            # in case template is a PathLike
+            self.template = env.get_template(str(template))
         else:
             self.template = env.from_string(template)
 
@@ -190,10 +207,11 @@ class Liquid:
     @classmethod
     def from_env(
         cls,
-        template: PathLike,
+        template: PathType,
         env: Environment,
         from_file: bool = None,
         filter_with_colon: bool = None,
+        filters_as_globals: bool = None,
         mode: str = None,
     ) -> "Liquid":
         """Initiate a template from a jinja environment
@@ -201,8 +219,8 @@ class Liquid:
         You should not specify any liquid-related extensions here. They will
         be added automatically.
 
-        No search path is allow to be passed here. Instead, use jinja2's loaders
-        or use the constructor to initialize a template.
+        No search path is allow to be passed here. Instead, use jinja2's
+        loaders or use the constructor to initialize a template.
 
         @Args:
             template: The template string or path of the template file
@@ -212,6 +230,8 @@ class Liquid:
             filter_with_colon: Whether enable to use colon to separate filter
                 and its arguments (i.e. `{{a | filter: arg}}`). If False, will
                 fallback to use parentheses (`{{a | filter(arg)}}`)
+            filters_as_globals: Whether also use filters as globals
+                Only works in wild mode
             mode: The mode of the engine.
                 - standard: Most compatibility with the standard liquid engine
                 - wild: The liquid- and jinja-compatible mode
@@ -225,5 +245,6 @@ class Liquid:
             env=env,
             from_file=from_file,
             filter_with_colon=filter_with_colon,
+            filters_as_globals=filters_as_globals,
             mode=mode,
         )
